aboutsummaryrefslogtreecommitdiff
path: root/bfd/elfxx-x86.h
diff options
context:
space:
mode:
authorH.J. Lu <hjl.tools@gmail.com>2017-10-06 16:45:37 -0700
committerH.J. Lu <hjl.tools@gmail.com>2017-10-06 16:45:37 -0700
commit99180bccaf09413c9ddb28e51fa30f1ca4966583 (patch)
treed2cab26615c7ff726be484d995b832a55ccbefc9 /bfd/elfxx-x86.h
parent98b273dc13b1e45db8c66821efc9e514884f3c25 (diff)
downloadbinutils-99180bccaf09413c9ddb28e51fa30f1ca4966583.zip
binutils-99180bccaf09413c9ddb28e51fa30f1ca4966583.tar.gz
binutils-99180bccaf09413c9ddb28e51fa30f1ca4966583.tar.bz2
x86: Update UNDEFINED_WEAK_RESOLVED_TO_ZERO comments
* elfxx-x86.h (UNDEFINED_WEAK_RESOLVED_TO_ZERO): Update comments.
Diffstat (limited to 'bfd/elfxx-x86.h')
-rw-r--r--bfd/elfxx-x86.h11
1 files changed, 4 insertions, 7 deletions
diff --git a/bfd/elfxx-x86.h b/bfd/elfxx-x86.h
index 8e78b7e..a2f5fc2 100644
--- a/bfd/elfxx-x86.h
+++ b/bfd/elfxx-x86.h
@@ -49,13 +49,10 @@
#define SYMBOL_REFERENCES_LOCAL_P(INFO, H) \
_bfd_x86_elf_link_symbol_references_local ((INFO), (H))
-/* Is a undefined weak symbol which is resolved to 0. Reference to an
- undefined weak symbol is resolved to 0 when building executable if
- it isn't dynamic and
- 1. Has non-GOT/non-PLT relocations in text section. Or
- 2. Has no GOT/PLT relocation.
- Local undefined weak symbol is always resolved to 0.
- */
+/* TRUE if an undefined weak symbol should be resolved to 0. Local
+ undefined weak symbol is always resolved to 0. Reference to an
+ undefined weak symbol is resolved to 0 in executable if undefined
+ weak symbol should be resolved to 0 (zero_undefweak > 0). */
#define UNDEFINED_WEAK_RESOLVED_TO_ZERO(INFO, EH) \
((EH)->elf.root.type == bfd_link_hash_undefweak \
&& (SYMBOL_REFERENCES_LOCAL_P ((INFO), &(EH)->elf) \